SjConfig class

Constructors

SjConfig({required String clientId, Language language = Language.vn, Environment environment = Environment.uat})

Properties

clientId String
final
environment Environment
final
hashCode int
The hash code for this object.
no setterinherited
language Language
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited