MethodChannelSjSdkTesting class

Inheritance

Constructors

MethodChannelSjSdkTesting()

Properties

hashCode int
The hash code for this object.
no setterinherited
isInitialized Future<bool>
no setteroverride
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flightRedemption(String token) Future<void>
override
initEnvironment(String env) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointExchange() Future<void>
override
signIn() Future<AuthModel>
override
signUp() Future<AuthModel>
override
toString() String
A string representation of this object.
inherited
userProfile(String token) Future<Map<String, dynamic>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited